=============
OpenAPI Specs
=============

Module: :mod:`jupyterlab_server.spec`
=====================================

.. automodule:: jupyterlab_server.spec

.. currentmodule:: jupyterlab_server.spec

.. autofunction:: get_openapi_spec

.. autofunction:: get_openapi_spec_dict
